OBF: O'Brien-Flemming error spending function.

View source: R/OBF.R

OBFR Documentation

O'Brien-Flemming error spending function.

Description

Computes the cumulative Type I error spending function corresponding to the two-sided O'Brien-Flemming group sequential design.

Usage

OBF(t, alpha = 0.05)

Arguments

t

Mumeric vector of information fractions, typically in (0,1), where t=1 corresponds to the final analysis.

alpha

Overall two-sided Type I error level. Default is 0.05.

Value

A numeric vector giving the cumulative type I error spent at each information fraction t under the O'Brien-Flemming spending function.

References

Jennison, C. and Turnbull, B. W. (2000). Group Sequential Methods with Applications to Clinical Trials. Chapman and Hall/CRC.

Examples

# Two-interim analyses at 50% and 75% maximum information and a final analysis
OBF(t = c(0.5, 0.7, 1))

gsMeanFreq documentation built on Feb. 17, 2026, 1:07 a.m.