find.Delta.given.power: Function to solve for the mean frequency effect size given...

View source: R/find.Delta.given.power.R

find.Delta.given.powerR Documentation

Function to solve for the mean frequency effect size given target power for one-sample simulations.

Description

Computes the mean frequency difference parameter \Delta that achieves a specified power for a two-sided group sequential test.

Usage

find.Delta.given.power(K, timing, alpha, power, Imax)

Arguments

K

Number of analysis (including the final analysis).

timing

Numeric vector of information fractions at each analysis, with values in (0, 1) and length equal to K.

alpha

Overall Type I error.

power

Target power of thw group sequenctial test.

Imax

Maximum information at the final analysis.

Value

A numeric value giving the mean frequency effect size \Delta that achieves the specified power.

Examples

# Toy Example: n = 800, two interim analysi planned at 50% and
# 75% if maximum information, along with a final analysis
# at 100% maximum information. Assuming the maximum
# information is 100, overall Type I error at 0.05 and power at 0.8.
find.Delta.given.power(K = 3, timing = c(0.5, 0.75, 1),
 alpha = 0.05, power = 0.8, Imax = 100)

gsMeanFreq documentation built on Feb. 17, 2026, 1:07 a.m.