find.beta.trt: Function to solve for treatment effect size given target...

View source: R/find.beta.trt.R

find.beta.trtR Documentation

Function to solve for treatment effect size given target power for two-sample tests.

Description

Computes the treatment effect parameter beta.trt that achieves a specified power for a two-sided Wald-type test under a normal approximation. The calculation assumes that the test statistic Q is asymptotically normal with mean proportional to the treatment effect and variance var.

Usage

find.beta.trt(power = 0.8, power.c, var)

Arguments

power

Target power for the two-sided test, default is 0.8.

power.c

Positive numeric constant relating the mean of the test statistic under the alternative hypothesis to the treatment effect.

var

Variance of the test statistic Q under the alternative hypothesis.

Value

A numeric value giving the treatment effect parameter.


gsMeanFreq documentation built on Feb. 17, 2026, 1:07 a.m.