find.lambda_0.given.mu0: Function to solve for the baseline recurrent event rate given...

View source: R/find.lambda_0.given.mu0.R

find.lambda_0.given.mu0R Documentation

Function to solve for the baseline recurrent event rate given a target mean frequency for one-sample simulations.

Description

Computes the value of the baseline recurrent event rate parameter.

Usage

find.lambda_0.given.mu0(lambda_star, gamma_shape, gamma_scale, t, mu0)

Arguments

lambda_star

Rate parameter of an exponential distribution in generating the terminal event.

gamma_shape

Shape parameter of the Gamma frailty distribution.

gamma_scale

Scale parameter of the Gamma frailty distribution.

t

Event time (time since enrollment) at which the mean frequency value mu0 is defined.

mu0

Target value of the mean frequency function at time t.

Value

A numeric value giving the baseline recurrent event rate \lambda_0 that satisfies \mu(t) = \mu(0).

Examples

find.lambda_0.given.mu0(lambda_star = 0.1, gamma_shape = 2, gamma_scale = 0.5, t = 1, mu0 = 2)

gsMeanFreq documentation built on Feb. 17, 2026, 1:07 a.m.