| OBF | R Documentation |
Computes the cumulative Type I error spending function corresponding to the two-sided O'Brien-Flemming group sequential design.
OBF(t, alpha = 0.05)
t |
Mumeric vector of information fractions, typically in |
alpha |
Overall two-sided Type I error level. Default is |
A numeric vector giving the cumulative type I error spent at each information fraction t
under the O'Brien-Flemming spending function.
Jennison, C. and Turnbull, B. W. (2000). Group Sequential Methods with Applications to Clinical Trials. Chapman and Hall/CRC.
# Two-interim analyses at 50% and 75% maximum information and a final analysis
OBF(t = c(0.5, 0.7, 1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.