| True.mu | R Documentation |
Computes the theoretical mean frequency function for the composite endpoint under the assumed data-generating mechanisim. The calculation uses the parameters stored in the simulated data.
True.mu(data, t)
data |
A data frame generated by |
t |
A numeric vector specifying event times (time since enrollment) at which the true value of the mean frequency is evaluated. |
A numeric vector giving the true mean frequency evaluated at t.
Mao L, Lin DY. Semiparametric regression for the weighted composite endpoint of recurrent and terminal events. Biostatistics. 2016 Apr; 17(2) :390-403.
df <- Onesample.generate.sequential(size = 200, recruitment = 3, calendar = 5,
random.censor.rate = 0.05, seed = 1123)
True.mu(data = df, t = c(1.5, 2.9, 4.6))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.