View source: R/TwoSample.Estimator.GT.sequential.R
| TwoSample.Estimator.GT.sequential | R Documentation |
Computes a two-sample generalized t-test statistic for composite endpoints consisting of recurrent events and a terminal event, using data observed up to a given calendar time. Event times are converted from the calendar-time scale to the event-time scale (time since enrollment).
TwoSample.Estimator.GT.sequential(data, tau = 3)
data |
A data frame generated by |
tau |
Positive numeric value specifying the upper bound of event time for the integration. Default is |
A list with components:
Q: Value of the generalized t-test statistics integrated over [0, tau].
var: Estimated asymptotic variance of Q.
const: Scaling constant used in the variance estimation.
# Two-sample generalized-t statistic: null hypothesis
df <- TwoSample.generate.sequential(sizevec = c(200, 200),
beta.trt = 0, calendar = 5, recruitment = 3,
random.censor.rate = 0.05, seed = 2026)
TwoSample.Estimator.GT.sequential(data = df, tau = 3)
# Two-sample generalized-t statistic: alternative hypothesis
df2 <- TwoSample.generate.sequential(sizevec = c(200, 200),
beta.trt = 0.8, calendar = 5, recruitment = 3,
random.censor.rate = 0.05, seed = 2026)
TwoSample.Estimator.GT.sequential(data = df2, tau = 3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.