View source: R/TwoSample.Estimator.TTFE.sequential.R
| TwoSample.Estimator.TTFE.sequential | R Documentation |
Computes a two-sample TTFE test statistics by retaining only the first observed event for each subject and applying a standard log-rank test. This function is intended as a comparator or benchmark to the mean-frequency based estimator implemented elsewhere in the package.
TwoSample.Estimator.TTFE.sequential(data)
data |
A data frame generated by |
A list with:
Z.stat: The ordinary log-rank statistics on the Z-scale, defined as the square root of the chi-square
statistic from survdiff().
var: The estimated variance of the test statistic. extracted from the log-rank test variance matrix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.