View source: R/find.beta.trt.R
| find.beta.trt | R Documentation |
Computes the treatment effect parameter beta.trt that achieves a specified power for a two-sided Wald-type
test under a normal approximation. The calculation assumes that the test statistic Q is asymptotically normal
with mean proportional to the treatment effect and variance var.
find.beta.trt(power = 0.8, power.c, var)
power |
Target power for the two-sided test, default is |
power.c |
Positive numeric constant relating the mean of the test statistic under the alternative hypothesis to the treatment effect. |
var |
Variance of the test statistic |
A numeric value giving the treatment effect parameter.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.