View source: R/find.lambda_0.given.mu0.R
| find.lambda_0.given.mu0 | R Documentation |
Computes the value of the baseline recurrent event rate parameter.
find.lambda_0.given.mu0(lambda_star, gamma_shape, gamma_scale, t, mu0)
lambda_star |
Rate parameter of an exponential distribution in generating the terminal event. |
gamma_shape |
Shape parameter of the Gamma frailty distribution. |
gamma_scale |
Scale parameter of the Gamma frailty distribution. |
t |
Event time (time since enrollment) at which the mean frequency value |
mu0 |
Target value of the mean frequency function at time |
A numeric value giving the baseline recurrent event rate \lambda_0 that satisfies \mu(t) = \mu(0).
find.lambda_0.given.mu0(lambda_star = 0.1, gamma_shape = 2, gamma_scale = 0.5, t = 1, mu0 = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.